@@ -2,16 +2,20 @@
 
 import logging
 import re
+import jwt
 
 from django.contrib.auth.hashers import check_password
 from django.contrib.auth.hashers import make_password
-import jwt
 from rest_framework.permissions import AllowAny
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-from config.config import Config
-from xj_user.models import *
+from main.settings import BASE_DIR
+
+from ..models import *
+from ..utils.j_config import JConfig
+
+root_config = JConfig.get_section(str(BASE_DIR) + '/config.ini', 'xj_user', encode='utf-8-sig')
 
 # from django.conf import settings
 
@@ -100,7 +104,7 @@ class UserPassword(APIView):
             user_id=t_user.id,
             password=make_password(new_password, None, 'pbkdf2_sha1'),
             plaintext=new_password,
-            token=jwt.encode({'account': account}, Config.getIns().get('xj_user', 'JWT_SECRET_KEY', "")),
+            token=jwt.encode({'account': account}, root_config.get('JWT_SECRET_KEY', "")),
         )
         headers = {
             "Authorization": new_auth.token,
